﻿using System;
using System.Collections;
using System.Text;

using Cosmos.UserFrame;
using Cosmos.ServiceProvider;
using Cosmos.Common;
using Cosmos.CommonManager;
using System.Data;
using System.Globalization;

/*-----------------------------------------------------------------------------------------------*/
// 설      명 : 아워홈
// 작  성  자 : 
// 변경  이력 : 
/*-----------------------------------------------------------------------------------------------*/
namespace Cosmos.Service
{
    class OurHome : PaymentBase, IPaymentUs  
    {
        private IOurHome m_cDeviceOurHome = null;                                    

        public OurHome()
        {
            m_cDeviceOurHome = (IOurHome)sManager.InitServiceInstance(ServiceLists.AGENT_OLEDEVICE.DLL, ServiceLists.AGENT_OLEDEVICE.DEVICE_OURHOME);
        }

        #region SearchPayment 결제 조회
        /// <summary>
        /// 결제 조회
        /// </summary>
        /// <param name="aParam"></param>
        /// <param name="aRet"></param>
        /// <returns></returns>
        public string SearchPayment(string[] aParam, ref string[] aRet)
        {
            string sRet = UserCom.RST_ERR;

            string sPosMenuKey = "", sCardNo = "", sSearchType = "";

            try
            {
                m_cPayItem = new Column.TR_PAYMENT.DATA();      // 결과 저장 변수 생성

                sPosMenuKey = aParam[0];                     // 메뉴키
                sCardNo = aParam[1];                         // 카드번호
                sSearchType = aParam[2];                     // 검색구분 (1:RF, 2:사번)

                //sRet = ExecuteIrt(sTrType);
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sCardNo);
                CmUtil.ZeroFillClear(ref aParam);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion

        #region GetPayment 결제 정보 획득
        /// <summary>
        /// 결제 정보 획득
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public object GetPayment(string[] aParam)
        {
            return m_cPayItem;
        }
        #endregion

        #region SetPayment 결제 등록
        /// <summary>
        /// 결제 등록(SPC 임직원 할인)
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public string SetPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;

            string sPosMenuKey = "", sWCC = "", sInPutData = "", sCardData = "", sApprNo = "", sApprDate = "", sSawonInfo = "";
            double nPayAmt = 0;

            try
            {
                sPosMenuKey = aParam[0];                     // 메뉴키
                sWCC = aParam[1];                            // 입력구분
                sInPutData = aParam[2];                      // 입력데이터
                sCardData = aParam[3];                       // 카드데이터
                nPayAmt = CmUtil.DoubleParse(aParam[4]);     // 대상금액
                sApprDate = aParam[5];                       // 승인일자
                sApprNo = aParam[6];                         // 승인번호

                sSawonInfo = aParam[7];                      // 고객조회값

                if (sApprDate.Length == 8) sApprDate = CmUtil.MidH(sApprDate, 2, 6);   // 승인일자(YYMMDD)

                string siNqType = "";
                if (m_cTrnStatus.Head.TradeDiv == ItemConst.TRAN_DIV.NORMAL)
                    siNqType = PosConst.OURHOME_TRAN_TYPE.NORMAL;
                else
                    siNqType = PosConst.OURHOME_TRAN_TYPE.REFUND;

                m_cPayItem = new Column.TR_PAYMENT.DATA();      // 결과 저장 변수 생성

                m_cPayItem.PAY_WAY_CD = ItemConst.TR_ITEM_ID.EMP_PAY_ITEM;
                m_cPayItem.PAY_DTL_CD_01 = ItemConst.TR_ITEM_ID.EMP_PAY.OURHOME;

                sRet = ExecuteIrt(m_cTrnStatus.Head.TradeDiv, siNqType, sWCC, sInPutData, sCardData, nPayAmt, sApprDate, sApprNo, sSawonInfo);

                if (sRet != UserCom.RST_OK) return sRet;

                // 결제 아이템 추가
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);     // 결제 내역 받아 오기
                m_cPayItem.SEQ = alPayItem.Count + 1;
                alPayItem.Add(m_cPayItem);

                m_cDataService.UpdatePluAmount();       // 상품 합계금액 계산(거래해더)
                m_cDataService.UpdatePayAmount();       // 결제 금액 재 계산 처리

                //WinManager.ConfirmMessage(sPointType + " " + MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0067));
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sInPutData);
                CmUtil.ZeroFillClear(ref sCardData);
                CmUtil.ZeroFillClear(ref aParam);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion

        #region CancelPayment 결제 취소
        /// <summary>
        /// 결제 취소
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public string CancelPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;

            string sWCC = "", sCardData = "", sApprNo = "", sApprDate = "", sSawonInfo = "", siNqType = "", sPointType = "", sInPutType = "";
            double nPayAmt = 0;

            try
            {
                if (m_cTrnStatus.Head.TradeDiv != ItemConst.TRAN_DIV.NORMAL) return sRet;

                int nPayRow = CmUtil.IntParse(aParam[0]); // 취소할 행번호

                // 결제 내역 받아 오기
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);
                m_cPayItem = (Column.TR_PAYMENT.DATA)alPayItem[nPayRow];

                sInPutType = m_cPayItem.OCCUR_ENTRY_05;          // 입력구분
                sWCC = m_cPayItem.OCCUR_ENTRY_01;                // 입력데이터
                sCardData = m_cPayItem.OCCUR_ENTRY_22;           // 카드데이터
                nPayAmt = m_cPayItem.AMT_ENTRY_01;               // 대상금액
                sApprDate = m_cPayItem.OCCUR_ENTRY_03;           // 승인일자
                sApprNo = m_cPayItem.OCCUR_ENTRY_02;             // 승인번호
                sSawonInfo = m_cPayItem.OCCUR_ENTRY_15;          // 사원조회값

                siNqType = PosConst.OURHOME_TRAN_TYPE.REFUND;
                sPointType = GetPayDtlCdToPointType(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);

                sRet = ExecuteIrt(m_cTrnStatus.Head.TradeDiv, siNqType, sWCC, sCardData, sCardData, nPayAmt, sApprDate, sApprNo, sSawonInfo);
                if (sRet != UserCom.RST_OK) return sRet;

                m_cPayItem.CANCEL_DIV = PosConst.CANCEL_DIV.CANCEL;

                m_cDataService.UpdatePluAmount();       // 상품 합계금액 계산(거래해더)
                m_cDataService.UpdatePayAmount();       // 결제 금액 재 계산 처리

                //WinManager.ConfirmMessage(sPointType + " " + MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0068));

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sCardData);
                CmUtil.ZeroFillClear(ref aParam);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion

        #region RefundPayment 결제 반품
        /// <summary>
        /// 결제 반품
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public string RefundPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;
            string sWCC = "", sCardData = "", sApprNo = "", sApprDate = "", sSawonInfo = "", siNqType = "", sPointType = "", sInPutType = "";
            double nPayAmt = 0;

            try
            {
                int nPayRow = CmUtil.IntParse(aParam[0]); // 취소할 행번호

                // 결제 내역 받아 오기
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);
                m_cPayItem = (Column.TR_PAYMENT.DATA)alPayItem[nPayRow];

                if (m_cPayItem.OCCUR_ENTRY_08.ToString() != ItemConst.PAY_APP_DIV.NORMAL)
                {
                    //임의 등록 이면 승인 없이 데이터 처리
                    //WinManager.ConfirmMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0240));
                    m_cPayItem.OCCUR_ENTRY_06 = m_cPayItem.OCCUR_ENTRY_02;
                    m_cPayItem.OCCUR_ENTRY_07 = m_cPayItem.OCCUR_ENTRY_03;

                    sRet = UserCom.RST_OK;
                }
                else
                {
                    sInPutType = m_cPayItem.OCCUR_ENTRY_05;          // 입력구분
                    sWCC = m_cPayItem.OCCUR_ENTRY_01;                // 입력데이터
                    sCardData = m_cPayItem.OCCUR_ENTRY_22;           // 카드데이터
                    nPayAmt = m_cPayItem.AMT_ENTRY_01;               // 대상금액
                    sApprDate = m_cPayItem.OCCUR_ENTRY_03;           // 승인일자
                    sApprNo = m_cPayItem.OCCUR_ENTRY_02;             // 승인번호
                    sSawonInfo = m_cPayItem.OCCUR_ENTRY_15;          // 사원조회값

                    siNqType = PosConst.OURHOME_TRAN_TYPE.REFUND;
                    sPointType = GetPayDtlCdToPointType(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);

                    sRet = ExecuteIrt(m_cTrnStatus.Head.TradeDiv, siNqType, sWCC, sCardData, sCardData, nPayAmt, sApprDate, sApprNo, sSawonInfo);
                }
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sCardData);
                CmUtil.ZeroFillClear(ref aParam);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion

        #region SetMenualPayment
        public string SetMenualPayment(string[] aParam)
        {
            throw new NotImplementedException();
        }
        #endregion

        #region 조회 실행
        /// <summary>
        /// 조회 실행
        /// </summary>
        public string ExecuteIrt(string sTradeDiv, string siNqType, string sWCC, string sInPutData, string sCardData, double nPayAmt, string sApprDate, string sApprNo, string sSawonInfo)
        {
            string sRet = UserCom.RST_ERR;
            try
            {
                // 연습모드이면 연습 데이터 설정
                if (m_cPosStatus.Base.TrainingFlag == "1" || m_cPosStatus.Mst.TestStorYn == "1" ) return SetTrainingData(siNqType, sWCC, sInPutData, nPayAmt, sApprDate, sApprNo);

                // 조회
                sRet = MakeOurHome(sTradeDiv, siNqType, sWCC, sInPutData, sCardData, nPayAmt, sApprDate, sApprNo, sSawonInfo);
               if (sRet != UserCom.RST_OK) return sRet;

                // 결제구분 (1:결제, 2:할인)
                DataRow dr = PosMstManager.GetMstPayDc(new string[] { m_cPosStatus.Base.CmpCd, m_cPosStatus.Base.StoreNo, m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01 });

                string[] aRecvData = sSawonInfo.Split(new string[] { "^" }, StringSplitOptions.None);

                m_cPayItem.PAY_AMT = nPayAmt;

                m_cPayItem.PAY_DTL_CD_02 = "";                                                                          // 캠페인코드
                m_cPayItem.PAY_DTL_CD_03 = "0";                                                                         // 할인금액 아이템 적용여부
                m_cPayItem.PAY_DTL_CD_05 = PosConst.PAY_DC_TYPE.PAY;                                                    // 할인결제구분 (1:결제, 2:할인)

                m_cPayItem.AMT_ENTRY_01 = nPayAmt;                                                                      // 받은돈
                m_cPayItem.AMT_ENTRY_02 = 0;                                                                            // 제휴 할인 금액
                m_cPayItem.AMT_ENTRY_03 = CmUtil.DoubleParse(aRecvData[10]);                                            // 거래전 잔액
                m_cPayItem.AMT_ENTRY_04 = CmUtil.DoubleSubtraction(nPayAmt, CmUtil.DoubleParse(aRecvData[10]));         // 거래후 잔액
                m_cPayItem.AMT_ENTRY_05 = 0;

                m_cPayItem.OCCUR_ENTRY_01 = sInPutData;                                                                 // 카드번호
                m_cPayItem.OCCUR_ENTRY_02 = "";                                                                         // 승인번호
                m_cPayItem.OCCUR_ENTRY_03 = m_cPosStatus.Base.SaleDate;                                                 // 승인일자
                m_cPayItem.OCCUR_ENTRY_04 = DateTime.Now.ToString("HHmmss");                                            // 승인시간
                m_cPayItem.OCCUR_ENTRY_05 = sWCC;                                                                       // 입력 구분
                m_cPayItem.OCCUR_ENTRY_06 = sApprNo;                                                                    // 원승인번호
                m_cPayItem.OCCUR_ENTRY_07 = sApprDate;                                                                  // 원승인일자
                m_cPayItem.OCCUR_ENTRY_08 = ItemConst.PAY_APP_DIV.NORMAL;                                               // 승인구분
                m_cPayItem.OCCUR_ENTRY_10 = aRecvData[9].Trim();                                                        // 직원명
                m_cPayItem.OCCUR_ENTRY_15 = sSawonInfo.Trim();                                                           // 사원조회값
                m_cPayItem.OCCUR_ENTRY_16 = CmUtil.GetDataRowStr(dr, PosMst.MST_PAY_DC.DATA.APPR_VEND_CD);              // VAN 구분
                m_cPayItem.OCCUR_ENTRY_20 = GetPayDtlCdToPayDtlName(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);   // 결제수단명
                m_cPayItem.OCCUR_ENTRY_22 = sCardData;

                m_cPayItem.CANCEL_DIV = ItemConst.PAY_CANCEL_DIV.NORMAL;
                m_cPayItem.BILLSPR_NO = m_cTrnStatus.Sale.BillSplitNo;                                                  // 빌분리 번호

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sCardData);
                CmUtil.ZeroFillClear(ref sInPutData);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }

        /// <summary>
        /// 연습 데이터 설정
        /// </summary>
        /// <param name="siNqType"></param>
        /// <param name="sWCC"></param>
        /// <param name="sCardData"></param>
        /// <param name="nPayAmt"></param>
        /// <param name="sApprDate"></param>
        /// <param name="sApprNo"></param>
        /// <returns></returns>
        public string SetTrainingData(string siNqType, string sWCC, string sCardData, double nPayAmt, string sApprDate, string sApprNo)
        {
            string sRet = UserCom.RST_ERR;
            try
            {
                // 결제구분 (1:결제, 2:할인)
                DataRow dr = PosMstManager.GetMstPayDc(new string[] { m_cPosStatus.Base.CmpCd, m_cPosStatus.Base.StoreNo, m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01 });

                // 연습모드이면 연습 데이터 설정
                m_cPayItem.PAY_AMT = nPayAmt;

                m_cPayItem.PAY_DTL_CD_02 = "";                                                                          // 캠페인코드
                m_cPayItem.PAY_DTL_CD_03 = "0";                                                                         // 할인금액 아이템 적용여부
                m_cPayItem.PAY_DTL_CD_05 = PosConst.PAY_DC_TYPE.PAY;                                                    // 할인결제구분 (1:결제, 2:할인)

                m_cPayItem.AMT_ENTRY_01 = nPayAmt;                                                                      // 사용포인트
                m_cPayItem.AMT_ENTRY_02 = 0;                                                                            // 제휴 할인 금액
                m_cPayItem.AMT_ENTRY_03 = 0;                                                                            // 총포인트
                m_cPayItem.AMT_ENTRY_04 = 0;                                                                            // 가용포인트
                m_cPayItem.AMT_ENTRY_05 = 0;                                                                            // 잔여포인트

                m_cPayItem.OCCUR_ENTRY_01 = sCardData;                                                                  // 카드번호
                m_cPayItem.OCCUR_ENTRY_02 = "99999999";                                                                 // 승인번호
                m_cPayItem.OCCUR_ENTRY_03 = DateTime.Now.ToString("yyMMdd");                                            // 승인일자
                m_cPayItem.OCCUR_ENTRY_04 = DateTime.Now.ToString("HHmmss");                                            // 승인시간
                m_cPayItem.OCCUR_ENTRY_05 = sWCC;                                                                       // 입력 구분
                m_cPayItem.OCCUR_ENTRY_06 = sApprNo;                                                                    // 원승인번호
                m_cPayItem.OCCUR_ENTRY_07 = sApprDate;                                                                  // 원승인일자
                m_cPayItem.OCCUR_ENTRY_08 = ItemConst.PAY_APP_DIV.COMPULSION;                                           // 승인구분
                m_cPayItem.OCCUR_ENTRY_10 = "TRAINEE";                                                                  // 직원명
                m_cPayItem.OCCUR_ENTRY_16 = CmUtil.GetDataRowStr(dr, PosMst.MST_PAY_DC.DATA.APPR_VEND_CD);              // VAN 구분
                m_cPayItem.OCCUR_ENTRY_20 = GetPayDtlCdToPayDtlName(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);   // 결제수단명
                m_cPayItem.OCCUR_ENTRY_22 = sCardData;

                m_cPayItem.CANCEL_DIV = ItemConst.PAY_CANCEL_DIV.NORMAL;
                m_cPayItem.BILLSPR_NO = m_cTrnStatus.Sale.BillSplitNo;                                                  // 빌분리 번호

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sCardData);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion

        #region 요청 전문 생성
        ///요청 전문 생성
        private string MakeOurHome(string sTradeDiv, string siNqType, string sWCC, string sInPutData, string sCardData, double nPayAmt, string sApprDate, string sApprNo, string sSawonInfo)
        {
            string sSendData = string.Empty;
            string sRet = UserCom.RST_ERR;

            try
            {
                // 조회 info 
                // 1 ^해당고객수
                // 2 ^소속빌딩코드
                // 3 ^고객사코드
                // 4 ^고객사번
                // 5 ^RF_NO
                // 6 ^소속빌딩명
                // 7 ^고객사명
                // 8 ^부서명
                // 9 ^고객명
                //10 ^잔액
                //11 ^사용종료일자(사용일자가 결제일보다 작으면 사용 안되도록 체크해주세요)
                //12 ^카드사용여부('N'이면 사용 안되도록 체크해주세요)
                //13 ^선불/후불   (001:선분, 002:후불)
                //14 ^EMPLOYEE_SEQ(고객SEQ )

                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);     // 결제 내역 받아 오기               

                string[] aRecvData = sSawonInfo.Split(new string[] { "^" }, StringSplitOptions.None);
                string sApprID = PosMstManager.GetMstVan(ItemConst.TR_ITEM_ID.EMP_PAY_ITEM, ItemConst.TR_ITEM_ID.EMP_PAY.OURHOME, PosMst.MST_VAN.DATA.APPR_ID);

                DateTime dateValue = DateTime.ParseExact(m_cPosStatus.Base.SaleDate, "yyyyMMdd", null);

                string sIrtData = "";
                sIrtData += m_cPosStatus.Base.SaleDate;                           //RF결제정보=  매출일         VARCHAR(8)   '20140415'            
                sIrtData += "^" + sApprID;                                        //    ^사용빌딩코드   VARCHAR(5)   'FA001'                         
                sIrtData += "^" + aRecvData[2];                                   //    ^소속빌딩코드	VARCHAR(5)   (고객정보함수에 포함되어 있음)    
                sIrtData += "^" + m_cPosStatus.Base.PosNo;                        //    ^POS_NO         VARCHAR(3)   '01'                            
                sIrtData += "^" + m_cPosStatus.Base.TradeNo;                      //    ^BILL_NO        VARCHAR(6)   '0001'                          
                sIrtData += "^" + "";                                             //    ^CORN_CD        VARCHAR(2)   ''                              
                sIrtData += "^" + (alPayItem.Count + 1).ToString();               //    ^SEQ            NUMERIC(3)   '1'                             
                sIrtData += "^" + "";                                             //    ^사용빌딩명     VARCHAR(30)  ''                              
                sIrtData += "^" + aRecvData[6];                                   //    ^소속빌딩명	VARCHAR(30)  (고객정보함수에 포함되어 있음)      
                sIrtData += "^" + (int) dateValue.DayOfWeek;                      //    ^요일           VARCHAR(1)   '3' --'1':일, '2':월 ~ '7':토   
                sIrtData += "^" + DateTime.Now.ToString("HHmmss");                //    ^매출시간       VARCHAR(6)   '121212'                        
                sIrtData += "^" + "";                                             //    ^메뉴코드       VARCHAR(6)   ''                              
                sIrtData += "^" + "";                                             //    ^메뉴명         VARCHAR(30)  ''                              
                sIrtData += "^" + "";                                             //    ^식구분         VARCHAR(2)   ''                              
                sIrtData += "^" + "0";                                            //    ^식수           NUMERIC(7)   0                               
                sIrtData += "^" + aRecvData[5];                                   //    ^RF카드번호	VARCHAR(10)  (고객정보함수에 포함되어 있음)      
                sIrtData += "^" + "";                                             //    ^PP카드번호     VARCHAR(20)  ''                              
                sIrtData += "^" + aRecvData[3];                                   //    ^고객사 코드	VARCHAR(30)  (고객정보함수에 포함되어 있음)    
                sIrtData += "^" + aRecvData[7];                                   //    ^고객사 명      VARCHAR(30)  (고객정보함수에 포함되어 있음)  
                sIrtData += "^" + aRecvData[4];                                   //    ^고객 사번	VARCHAR(15)  (고객정보함수에 포함되어 있음)      
                sIrtData += "^" + aRecvData[9];                                   //    ^고객명		VARCHAR(30)  (고객정보함수에 포함되어 있음)        
                sIrtData += "^" + "";                                             //    ^PP_KIND        VARCHAR(6)   ''                              
                sIrtData += "^" + "";                                             //    ^DAM_CD         VARCHAR(3)   ''                              
                sIrtData += "^" + (siNqType == PosConst.OURHOME_TRAN_TYPE.NORMAL ? nPayAmt.ToString() : (nPayAmt * (-1)).ToString());   //    ^총사용액       NUMERIC(13)  3000                            
                sIrtData += "^" + "1";                                            //    ^수량           NUMERIC(7)   1                               
                sIrtData += "^" + (siNqType == PosConst.OURHOME_TRAN_TYPE.NORMAL ? nPayAmt.ToString() : (nPayAmt * (-1)).ToString());   //    ^RF사용액       NUMERIC(13)  3000                            
                sIrtData += "^" + "0";                                            //    ^PP사용액       NUMERIC(13)  0                               
                sIrtData += "^" + "";                                             //    ^식권           VARCHAR(5)   ''                              
                sIrtData += "^" + "0";                                            //    ^현금사용액     NUMERIC(13)  0                               
                sIrtData += "^" + "0";                                            //    ^할인금액       NUMERIC(13)  0                               
                sIrtData += "^" + siNqType;                                       //    ^판매구분       VARCHAR(2)   '003':정상, '013':반품          
                sIrtData += "^" + m_cPosStatus.Base.SaleDate;                     //    ^적용일자       VARCHAR(8)   '20140415'                      
                sIrtData += "^" + DateTime.Now.ToString("HHmmss");                //    ^적용시간       VARCHAR(6)   '121212'                        
                sIrtData += "^" + "";                                             //    ^ACHK           VARCHAR(15)  ''                              
                sIrtData += "^" + "";                                             //    ^BCHK           VARCHAR(15)  ''                              
                sIrtData += "^" + m_cPosStatus.Base.CmpCd;                        //    ^업장코드       VARCHAR(15)  'FF100'                         
                sIrtData += "^" + aRecvData[14];                                  //    ^고객SEQ        NUMERIC(2)   (고객정보함수에 포함되어 있음)  
                sIrtData += "^" + sApprDate;                                      //    ^원거래 매출일  VARCHAR(15)  '20151207'                      
                sIrtData += "^" + (siNqType == PosConst.OURHOME_TRAN_TYPE.NORMAL ? "" : (m_cTrnStatus.Head.OrgPosNo.Trim() == "" ? m_cTrnStatus.Head.PosNo : m_cTrnStatus.Head.OrgPosNo));         //    ^원거래 POS_NO  VARCHAR(3)   '01'                            
                sIrtData += "^" + (siNqType == PosConst.OURHOME_TRAN_TYPE.NORMAL ? "" : (m_cTrnStatus.Head.OrgTradeNo.Trim() == "" ? m_cTrnStatus.Head.TradeNo : m_cTrnStatus.Head.OrgTradeNo));   //    ^원거래 BILL_NO VARCHAR(6)   '0001'                          
                sIrtData += "|";

                // 요청 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, siNqType, "S", sCardData, nPayAmt.ToString(), sApprNo, sApprDate, "", "", "", sIrtData });

                string sResCD = m_cDeviceOurHome.Rf_TransData(sApprID, sIrtData, "1");
                if (CmUtil.MidH(sResCD, 0, 1) == "1") sRet = UserCom.RST_OK;

                // 응답 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, siNqType, "R"
                                                            , sCardData, nPayAmt.ToString()
                                                            , "", DateTime.Now.ToString("yyyyMMdd"), DateTime.Now.ToString("HHmmss")
                                                            , CmUtil.MidH(sResCD, 0, 1)
                                                            , ""
                                                            , sResCD });
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            finally
            {
                //여전법 대응!
                //////////////////////////////////////////////////////////////////////////////////
                CmUtil.ZeroFillClear(ref sInPutData);
                CmUtil.ZeroFillClear(ref sCardData);
                //////////////////////////////////////////////////////////////////////////////////
            }
            return sRet;
        }
        #endregion
    }
}
