﻿using System;
using System.Collections;
using System.Text;

using Cosmos.UserFrame;
using Cosmos.ServiceProvider;
using Cosmos.Common;
using Cosmos.CommonManager;
using System.Data;
using Newtonsoft.Json;

/*-----------------------------------------------------------------------------------------------*/
// 설      명 : 외상
// 작  성  자 : 
// 변경  이력 : 
/*-----------------------------------------------------------------------------------------------*/
namespace Cosmos.Service
{
    class SaleOnCustomer : PaymentBase, IPaymentUs
    {
        private ISalePluItemUs m_cPluService = null;                                // 판매 등록 관리

        public SaleOnCustomer()
        {
            m_cPluService = (ISalePluItemUs)sManager.InitServiceInstance(ServiceLists.BSV_SALE.DLL, ServiceLists.BSV_SALE.SALE_PLU_ITEM);
        }

        #region SearchPayment 결제 조회
        /// <summary>
        /// 결제 조회
        /// </summary>
        /// <param name="aParam"></param>
        /// <param name="aRet"></param>
        /// <returns></returns>
        public string SearchPayment(string[] aParam, ref string[] aRet)
        {
            string sRet = UserCom.RST_ERR;

            try
            {
                m_cPayItem = new Column.TR_PAYMENT.DATA();                  // 결과 저장 변수 생성

                string sPosMenuKey = aParam[0];                             // 메뉴키
                m_cPayItem.PAY_WAY_CD = aParam[1];                          // 결제 그룹코드
                m_cPayItem.PAY_DTL_CD_01 = aParam[2];                       // 결제 상세코드
                string sTranFlag = aParam[3];                               // 조회구분 (0:이름, 1:코드)
                string sCustType = aParam[4];                               // 고객구분 (0:개인, 1:법인)
                string sCustID = aParam[5];                                 // 고객 ID
                double nPayAmt = CmUtil.DoubleParse(aParam[6]);             // 외상금액 

                sRet = ExecuteIrt(PosConst.CANCEL_DIV.NORMAL, sPosMenuKey, sTranFlag, sCustType, sCustID, "",  nPayAmt, 0, ref aRet);
                if (sRet != UserCom.RST_OK) return sRet;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region GetPayment 결제 정보 획득
        /// <summary>
        /// 결제 정보 획득
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public object GetPayment(string[] aParam)
        {
            return m_cPayItem;
        }
        #endregion

        #region SetMenualPayment
        public string SetMenualPayment(string[] aParam)
        {
            throw new NotImplementedException();
        }
        #endregion

        #region SetPayment 결제 등록
        /// <summary>
        /// 결제 등록
        /// </summary>
        /// <param name="aParam"></param>
        /// <returns></returns>
        public string SetPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;

            try
            {
                m_cPayItem = new Column.TR_PAYMENT.DATA();                  // 결과 저장 변수 생성

                string sPosMenuKey = aParam[0];                             // 메뉴키
                m_cPayItem.PAY_WAY_CD = aParam[1];                          // 결제 그룹코드
                m_cPayItem.PAY_DTL_CD_01 = aParam[2];                       // 결제 상세코드
                string sTranFlag = aParam[3];                               // 거래구분 (0:외상, 1:외상취소)
                string sCustType = aParam[4];                               // 고객구분 (0:개인, 1:법인)
                string sCustID = aParam[5];                                 // 고객 ID
                string sCustNM = aParam[6];                                 // 고객 ID
                double nPayAmt = CmUtil.DoubleParse(aParam[7]);             // 외상금액 
                double nDCAmt = CmUtil.DoubleParse(aParam[8]);              // DC금액 

                // 상품 할인 적용
                sRet = GetSaleItemTotalDC(nDCAmt);
                if (sRet != UserCom.RST_OK) return sRet;

                string[] aRet = null;
                sRet = ExecuteIrt(PosConst.CANCEL_DIV.NORMAL, sPosMenuKey, sTranFlag, sCustType, sCustID, sCustNM, nPayAmt, nDCAmt, ref aRet);
                if (sRet != UserCom.RST_OK) return sRet;

                // 결제 아이템 추가
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);     // 결제 내역 받아 오기
                m_cPayItem.SEQ = alPayItem.Count + 1;
                alPayItem.Add(m_cPayItem);

                m_cDataService.UpdatePluAmount();       // 상품 합계금액 계산(거래해더)
                m_cDataService.UpdatePayAmount();       // 결제 금액 재 계산 처리

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                   System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region 결제 취소
        /// <summary>
        /// 결제 취소
        /// </summary>
        /// <returns></returns>
        public string CancelPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;

            try
            {
                if (m_cTrnStatus.Head.TradeDiv != ItemConst.TRAN_DIV.NORMAL) return sRet;

                int nPayRow = CmUtil.IntParse(aParam[0]); // 취소할 행번호

                // 결제 내역 받아 오기
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);
                m_cPayItem = (Column.TR_PAYMENT.DATA)alPayItem[nPayRow];

                string sPosMenuKey = ItemConst.IRT_INQ_TYPE.SALEONCREDIT_USE_INQ;                                       // 메뉴키
                string sTranFlag = "1";                                                                                 // 거래구분 (0:외상, 1:외상취소)
                string sCustType = m_cPayItem.OCCUR_ENTRY_11;                                                           // 고객구분 (0:개인, 1:법인)
                string sCustID = m_cPayItem.OCCUR_ENTRY_01;                                                             // 고객 ID
                string sCustNM = m_cPayItem.OCCUR_ENTRY_15;                                                             // 고객명
                double nPayAmt = m_cPayItem.AMT_ENTRY_01;                                                               // 외상금액 
                double nDCAmt = m_cPayItem.AMT_ENTRY_02;                                                                // DC금액 

                string[] aRet = null;
                sRet = ExecuteIrt(PosConst.CANCEL_DIV.CANCEL, sPosMenuKey, sTranFlag, sCustType, sCustID, sCustNM, nPayAmt, nDCAmt, ref aRet);
                if (sRet != UserCom.RST_OK) return sRet;

                if (nDCAmt > 0)     // 외상할인 있을때만 처리(2017.06.01)
                {
                    // 상품 할인 취소
                    sRet = GetSaleItemTotalDCCancel();
                    if (sRet != UserCom.RST_OK) return sRet;
                }

                m_cPayItem.CANCEL_DIV = PosConst.CANCEL_DIV.CANCEL;

                m_cDataService.UpdatePluAmount();       // 상품 합계금액 계산(거래해더)
                m_cDataService.UpdatePayAmount();       // 결제 금액 재 계산 처리

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region 결제 반품
        /// <summary>
        /// 결제 반품
        /// </summary>
        /// <returns></returns>
        public string RefundPayment(string[] aParam)
        {
            string sRet = UserCom.RST_ERR;

            try
            {
               // if (m_cTrnStatus.Head.TradeDiv == ItemConst.TRAN_DIV.NORMAL) return sRet;

                int nPayRow = CmUtil.IntParse(aParam[0]); // 취소할 행번호

                // 결제 내역 받아 오기
                ArrayList alPayItem = (ArrayList)StateObject.GetItemObject(Column.TR_PAYMENT.ITEM);
                m_cPayItem = (Column.TR_PAYMENT.DATA)alPayItem[nPayRow];

                if (m_cPayItem.OCCUR_ENTRY_08.ToString() != ItemConst.PAY_APP_DIV.NORMAL)
                {
                    //임의 등록 이면 승인 없이 데이터 처리
                    WinManager.ConfirmMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0240));
                    m_cPayItem.OCCUR_ENTRY_06 = m_cPayItem.OCCUR_ENTRY_02;
                    m_cPayItem.OCCUR_ENTRY_07 = m_cPayItem.OCCUR_ENTRY_03;

                }
                else
                {

                    string sPosMenuKey = ItemConst.IRT_INQ_TYPE.SALEONCREDIT_USE_INQ;                                       // 메뉴키
                    string sTranFlag = "1";                                                                                 // 거래구분 (0:외상, 1:외상취소)
                    string sCustType = m_cPayItem.OCCUR_ENTRY_11;                                                           // 고객구분 (0:개인, 1:법인)
                    string sCustID = m_cPayItem.OCCUR_ENTRY_01;                                                             // 고객 ID
                    string sCustNM = m_cPayItem.OCCUR_ENTRY_15;                                                             // 고객명
                    double nPayAmt = m_cPayItem.AMT_ENTRY_01;                                                               // 외상금액 
                    double nDCAmt = m_cPayItem.AMT_ENTRY_02;                                                                // DC금액 

                    string[] aRet = null;
                    sRet = ExecuteIrt(PosConst.CANCEL_DIV.CANCEL, sPosMenuKey, sTranFlag, sCustType, sCustID, sCustNM, nPayAmt, nDCAmt, ref aRet);
                    if (sRet != UserCom.RST_OK) return sRet;
                }
                // 상품 할인 취소 삭제(2017.06.01)
                //sRet = GetSaleItemTotalDCCancel();
                //if (sRet != UserCom.RST_OK) return sRet; 

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region 조회 실행
        /// <summary>
        /// 조회 실행
        /// </summary>
        public string ExecuteIrt(string sTradeDiv, string sPosMenuKey, string sTranFlag, string sCustType, string sCustID, string sCustNM, double nPayAmt, double nDCAmt, ref string[] aRet)
        {
            string sRet = UserCom.RST_ERR;
            Hashtable htRecvData = new Hashtable(); 

            try
            {
                aRet = new string[] { "" };
 
                // 연습모드이면 연습 데이터 설정
                if (m_cPosStatus.Base.TrainingFlag == "1" || m_cPosStatus.Mst.TestStorYn == "1") return SetTrainingData(sPosMenuKey, sTranFlag, sCustType, sCustID, sCustNM, nPayAmt, nDCAmt);

                // 조회
                sRet = ExecuteHostIrt(sTradeDiv, sPosMenuKey, sTranFlag, sCustType, sCustID, nPayAmt, ref htRecvData);
                if (sRet != UserCom.RST_OK) return sRet;

                if (sPosMenuKey == ItemConst.IRT_INQ_TYPE.SALEONCREDIT_CUSTINQ)
                {    // 조회시
                    aRet = htRecvData[Column.IQ_SALEONCREDIT_CUSTINQ_RSP.DATA.CUSTOMER_VALUE].ToString().Split(new string[] { "#~" }, StringSplitOptions.None);
                }

                // 결제구분 (1:결제, 2:할인)
                DataRow dr = PosMstManager.GetMstPayDc(new string[] { m_cPosStatus.Base.CmpCd, m_cPosStatus.Base.StoreNo, m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01 });
                 
                m_cPayItem.PAY_AMT = nPayAmt;

                m_cPayItem.PAY_DTL_CD_02 = "";                                                                          // 캠페인코드
                m_cPayItem.PAY_DTL_CD_03 = "1";                                                                         // 할인금액 아이템 적용 여부 (0:미적용, 1:적용)
                m_cPayItem.PAY_DTL_CD_04 = "";                                                                          // 상품코드
                m_cPayItem.PAY_DTL_CD_05 = PosConst.PAY_DC_TYPE.PAY;                                                    // 할인결제구분 (1:결제, 2:할인)

                m_cPayItem.QTY_ENTRY_01 = 0;                                                                            // 수량
                m_cPayItem.QTY_ENTRY_02 = 0;    
                m_cPayItem.QTY_ENTRY_03 = 0;
                m_cPayItem.QTY_ENTRY_04 = 0;
                m_cPayItem.QTY_ENTRY_05 = 0;

                m_cPayItem.AMT_ENTRY_01 = nPayAmt;                                                                      // 받은돈
                m_cPayItem.AMT_ENTRY_02 = nDCAmt;                                                                       // 할인금액
                m_cPayItem.AMT_ENTRY_03 = 0;
                m_cPayItem.AMT_ENTRY_04 = 0;
                m_cPayItem.AMT_ENTRY_05 = 0;
                m_cPayItem.AMT_ENTRY_08 = 0;
                m_cPayItem.AMT_ENTRY_09 = 0;
                m_cPayItem.AMT_ENTRY_10 = 0;

                m_cPayItem.OCCUR_ENTRY_01 = sCustID;                                                                    // 카드번호
                m_cPayItem.OCCUR_ENTRY_02 = "";                                                                         // 승인번호
                m_cPayItem.OCCUR_ENTRY_03 = "";                                                                         // 승인일자
                m_cPayItem.OCCUR_ENTRY_04 = "";                                                                         // 승인시간
                m_cPayItem.OCCUR_ENTRY_05 = "";                                                                         // 입력 구분
                m_cPayItem.OCCUR_ENTRY_06 = "";                                                                         // 원승인번호
                m_cPayItem.OCCUR_ENTRY_07 = "";                                                                         // 원승인일자
                m_cPayItem.OCCUR_ENTRY_08 = ItemConst.PAY_APP_DIV.NORMAL;                                               // 승인구분
                m_cPayItem.OCCUR_ENTRY_10 = sTranFlag;                                                                  // 조회구분(0:이름, 1:코드)
                m_cPayItem.OCCUR_ENTRY_11 = sCustType;                                                                  // 고객형태(0:개인, 1:법인) 
                m_cPayItem.OCCUR_ENTRY_15 = sCustNM;                                                                    // 고객명
                m_cPayItem.OCCUR_ENTRY_13 = "";                                                                         //
                m_cPayItem.OCCUR_ENTRY_16 = CmUtil.GetDataRowStr(dr, PosMst.MST_PAY_DC.DATA.APPR_VEND_CD);              // VAN 구분
                m_cPayItem.OCCUR_ENTRY_20 = GetPayDtlCdToPayDtlName(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);   // 결제수단명
                m_cPayItem.OCCUR_ENTRY_22 = "";
                m_cPayItem.BILLSPR_NO = m_cTrnStatus.Sale.BillSplitNo;                                                  // 빌분리 번호

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
                sRet = UserCom.RST_ERR;
            }
            return sRet;
        }

        /// <summary>
        /// 연습 데이터 설정
        /// </summary>
        public string SetTrainingData(string sPosMenuKey, string sTranFlag, string sCustType, string sCustID, string sCustNM, double nPayAmt, double nDCAmt)
        {
            string sRet = UserCom.RST_ERR;
            try
            {
                // 연습모드이면 연습 데이터 설정

                // 결제구분 (1:결제, 2:할인)
                DataRow dr = PosMstManager.GetMstPayDc(new string[] { m_cPosStatus.Base.CmpCd, m_cPosStatus.Base.StoreNo, m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01 });

                m_cPayItem.PAY_AMT = nPayAmt;

                m_cPayItem.PAY_DTL_CD_02 = "";                                                                          // 캠페인코드
                m_cPayItem.PAY_DTL_CD_03 = "1";                                                                         // 할인금액 아이템 적용 여부 (0:미적용, 1:적용)
                m_cPayItem.PAY_DTL_CD_04 = "";                                                                          // 상품코드
                m_cPayItem.PAY_DTL_CD_05 = PosConst.PAY_DC_TYPE.PAY;                                                    // 할인결제구분 (1:결제, 2:할인)

                m_cPayItem.QTY_ENTRY_01 = 0;                                                                            // 수량
                m_cPayItem.QTY_ENTRY_02 = 0;
                m_cPayItem.QTY_ENTRY_03 = 0;
                m_cPayItem.QTY_ENTRY_04 = 0;
                m_cPayItem.QTY_ENTRY_05 = 0;

                m_cPayItem.AMT_ENTRY_01 = nPayAmt;                                                                      // 받은돈
                m_cPayItem.AMT_ENTRY_02 = nDCAmt;                                                                       // 할인금액
                m_cPayItem.AMT_ENTRY_03 = 0;
                m_cPayItem.AMT_ENTRY_04 = 0;
                m_cPayItem.AMT_ENTRY_05 = 0;
                m_cPayItem.AMT_ENTRY_08 = 0;
                m_cPayItem.AMT_ENTRY_09 = 0;
                m_cPayItem.AMT_ENTRY_10 = 0;

                m_cPayItem.OCCUR_ENTRY_01 = sCustID;                                                                    // 카드번호
                m_cPayItem.OCCUR_ENTRY_02 = "";                                                                         // 승인번호
                m_cPayItem.OCCUR_ENTRY_03 = "";                                                                         // 승인일자
                m_cPayItem.OCCUR_ENTRY_04 = "";                                                                         // 승인시간
                m_cPayItem.OCCUR_ENTRY_05 = "";                                                                         // 입력 구분
                m_cPayItem.OCCUR_ENTRY_06 = "";                                                                         // 원승인번호
                m_cPayItem.OCCUR_ENTRY_07 = "";                                                                         // 원승인일자
                m_cPayItem.OCCUR_ENTRY_08 = ItemConst.PAY_APP_DIV.COMPULSION;                                           // 승인구분
                m_cPayItem.OCCUR_ENTRY_10 = sTranFlag;                                                                  // 조회구분(0:이름, 1:코드)
                m_cPayItem.OCCUR_ENTRY_11 = sCustType;                                                                  // 고객형태(0:개인, 1:법인) 
                m_cPayItem.OCCUR_ENTRY_15 = sCustNM;                                                                    // 고객명
                m_cPayItem.OCCUR_ENTRY_13 = "";                                                                         //  
                m_cPayItem.OCCUR_ENTRY_16 = CmUtil.GetDataRowStr(dr, PosMst.MST_PAY_DC.DATA.APPR_VEND_CD);              // VAN 구분
                m_cPayItem.OCCUR_ENTRY_20 = GetPayDtlCdToPayDtlName(m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01);   // 결제수단명
                m_cPayItem.OCCUR_ENTRY_22 = "";

                m_cPayItem.CANCEL_DIV = ItemConst.PAY_CANCEL_DIV.NORMAL;                                                // 취소여부
                m_cPayItem.BILLSPR_NO = m_cTrnStatus.Sale.BillSplitNo;                                                  // 빌분리 번호

                sRet = UserCom.RST_OK;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region Host 조회 실행
        /// <summary>
        /// Host 조회 실행
        /// </summary>
        public string ExecuteHostIrt(string sTradeDiv, string sPosMenuKey, string sTranFlag, string sCustType, string sCustID, double nSaleAmt, ref Hashtable htRecvData)
        {
            int iRecvTimeOut = 10000; 
            string sRet = UserCom.RST_ERR; 
            Hashtable htSendData = new Hashtable();

            try
            {
                if (m_cPayItem.PAY_WAY_CD != ItemConst.TR_ITEM_ID.CREDIT_ITEM ) return null;

                if (sPosMenuKey == ItemConst.IRT_INQ_TYPE.SALEONCREDIT_CUSTINQ)
                {
                    // 외상 조회
                    htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.INQ_TYPE, sPosMenuKey);
                    
                    //#20171016 스퀘어 점포일 때 실점포 코드로 넘기기 start, phj
                    //기존
                    //htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.STOR_CD, m_cPosStatus.Base.StoreNo);
                    //변경
                    htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.STOR_CD, m_cPosStatus.Base.SubShopNo);
                    //#20171016 스퀘어 점포일 때 실점포 코드로 넘기기 end, phj

                    htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.INQ_FLAG, sTranFlag);
                    htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.CUSTOMER_TY, sCustType);
                    htSendData.Add(Column.IQ_SALEONCREDIT_CUSTINQ_REQ.DATA.CUSTOMER_ID, sCustID);

                    // 요청 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                    m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, sPosMenuKey, "S", sCustID, nSaleAmt.ToString(), "", "", "", "", "", JsonConvert.SerializeObject(htSendData) });

                    sRet = m_cDataCommon.ExecutePosIrt(ItemConst.COMM_MSG_TYPE.POSIRT, m_cPosStatus.Base.CommSvrIp, (int)m_cPosStatus.Base.PayInqPort, iRecvTimeOut, htSendData, ref htRecvData);
                    if (sRet != UserCom.RST_OK)
                    { 
                        WinManager.ErrorMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0214));

                        sRet = UserCom.RST_ERR;
                        return sRet;
                    }

                    // 응답 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                    m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, sPosMenuKey, "R"
                                                            , sCustID,nSaleAmt.ToString()
                                                            , "", "", ""
                                                            , htRecvData[Column.IQ_SALEONCREDIT_CUSTINQ_RSP.DATA.RES_CD].ToString()
                                                            , ""
                                                            , JsonConvert.SerializeObject(htRecvData) });

                    if (htRecvData[Column.IQ_SALEONCREDIT_CUSTINQ_RSP.DATA.RES_CD].ToString() != "00")
                    {
                        WinManager.ErrorMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0214) + " (" + htRecvData[Column.IQ_SALEONCREDIT_CUSTINQ_RSP.DATA.RES_CD].ToString() + ")" + "\n\r");

                        sRet = UserCom.RST_ERR;
                        return sRet;
                    }
                }
                else if (sPosMenuKey == ItemConst.IRT_INQ_TYPE.SALEONCREDIT_USE_INQ)
                {
                    // 외상 사용
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.INQ_TYPE, sPosMenuKey);
                    

                    //#20171016 스퀘어 점포일 때 실점포 코드로 넘기기 start, phj
                    //기존
                    //htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.STOR_CD, m_cPosStatus.Base.StoreNo);
                    //변경
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.STOR_CD, m_cPosStatus.Base.SubShopNo);
                    //#20171016 스퀘어 점포일 때 실점포 코드로 넘기기 end, phj

                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.POS_NO, m_cPosStatus.Base.PosNo);
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.SALE_DT, m_cPosStatus.Base.SaleDate);
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.SALE_GBN, sTranFlag);
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.CUST_ID, sCustID);
                    htSendData.Add(Column.IQ_SALEONCREDIT_USE_REQ.DATA.SALE_AMT, nSaleAmt.ToString());

                    // 요청 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                    m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, sPosMenuKey, "S", sCustID, nSaleAmt.ToString(), "", "", "", "", "", JsonConvert.SerializeObject(htSendData) });

                    sRet = m_cDataCommon.ExecutePosIrt(ItemConst.COMM_MSG_TYPE.POSIRT, m_cPosStatus.Base.CommSvrIp, (int)m_cPosStatus.Base.BizInqPort, iRecvTimeOut, htSendData, ref htRecvData);
                    if (sRet != UserCom.RST_OK)
                    {
                        WinManager.ErrorMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0216));

                        sRet = UserCom.RST_ERR;
                        return sRet;
                    }

                    // 요청 - 승인로그 저장   (판매구분, [0]결제수단, [1]결제상세코드, [2]전문구분, [3]요청구분, [4]카드번호, [5]결제금액, [6]승인번호, [7]승인일자, [8]승인시간, [9]응답상태값, [10]응답메시지, [11]전문)
                    m_cDataCommon.SetSaleApprLog(sTradeDiv, new string[] { m_cPayItem.PAY_WAY_CD, m_cPayItem.PAY_DTL_CD_01, sPosMenuKey, "R"
                                                            , sCustID, nSaleAmt.ToString()
                                                            , "", "", ""
                                                            , htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_CD].ToString()
                                                            , htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_MSG].ToString()
                                                            , JsonConvert.SerializeObject(htRecvData) });

                    // Rhee, 2017/09/22 딜리버리 외매(선매) 추가 -- START
                    // 기존
                    //if (htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_CD].ToString() != "00")
                    // 변경
                    if ((htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_CD].ToString() != "00") && (m_cPayItem.PAY_DTL_CD_01 != "01"))
                    // Rhee, 2017/09/22 딜리버리 외매(선매) 추가 -- END
                    {
                        WinManager.ErrorMessage(MessageManager.GetErrorMessage(POS_MESSAGE.ERROR.MSG_0216) + " (" + htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_CD].ToString() + ")" + "\n\r" + htRecvData[Column.IQ_SALEONCREDIT_USE_RSP.DATA.RES_MSG].ToString());

                        sRet = UserCom.RST_ERR;
                        return sRet;
                    }
                }

                sRet = UserCom.RST_OK;
                return sRet;
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion


        #region 전체상품 할인 처리
        /// <summary>
        /// 전체 상품중 할인 대상금액 조회
        /// </summary>
        /// <returns></returns>
        public double GetSaleItemDCTargerAmt(bool bAllMode)
        {
            double nDCSum = 0;

            string sRet = UserCom.RST_ERR;

            try
            {
                nDCSum = 0;

                // 상품정보
                ArrayList aSaleItem = (ArrayList)StateObject.GetItemObject(Column.TR_PLU.ITEM);

                for (int iRow = 0; iRow < aSaleItem.Count; iRow++)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iRow];

                    if (cSaleItem.CANCEL_DIV == PosConst.CANCEL_DIV.CANCEL || cSaleItem.CANCEL_DIV_MAIN == PosConst.CANCEL_DIV.CANCEL) continue;// 지정취소
                    if (cSaleItem.DC_DIV == ItemConst.PLU_DC_DIV.FREE) continue;                                                                // 서비스(무료)
                    if (cSaleItem.ITEM_DIV != ItemConst.PLU_ITEM_DIV.NORMAL && bAllMode != true) continue;                                      // 상품구분(일반)
                    if (cSaleItem.NONSALES_RSN_CD != "0") continue;                                                                             // 비매출구분
                    if (cSaleItem.BILLSPR_NO != m_cTrnStatus.Sale.BillSplitNo) continue;                                                        // 빌분리번호
                    if (cSaleItem.BILL_AMT <= 0) continue;                                                                                      // 영수금액
                    if (cSaleItem.DC_PRMT_YN != "0") continue;                                                                                  // 할인가능 여부 

                    // 할인 대상 금액 sum
                    nDCSum = CmUtil.DoubleAdd(nDCSum, cSaleItem.BILL_AMT);
                }
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return nDCSum;
        }

        /// <summary>
        /// 전체 상품중 임의할인 금액 Sum 조회
        /// </summary>
        /// <returns></returns>
        public double GetSaleItemDCAmt(bool bAllMode)
        {
            double nDCSum = 0;

            string sRet = UserCom.RST_ERR;

            try
            {
                nDCSum = 0;

                // 상품정보
                ArrayList aSaleItem = (ArrayList)StateObject.GetItemObject(Column.TR_PLU.ITEM);

                for (int iRow = 0; iRow < aSaleItem.Count; iRow++)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iRow];

                    if (cSaleItem.CANCEL_DIV == PosConst.CANCEL_DIV.CANCEL || cSaleItem.CANCEL_DIV_MAIN == PosConst.CANCEL_DIV.CANCEL) continue;// 지정취소
                    if (cSaleItem.DC_DIV == ItemConst.PLU_DC_DIV.FREE) continue;                                                                // 서비스(무료)
                    if (cSaleItem.ITEM_DIV != ItemConst.PLU_ITEM_DIV.NORMAL && bAllMode != true) continue;                                      // 상품구분(일반)
                    if (cSaleItem.NONSALES_RSN_CD != "0") continue;                                                                             // 비매출구분
                    if (cSaleItem.BILLSPR_NO != m_cTrnStatus.Sale.BillSplitNo) continue;                                                        // 빌분리번호
                    if (cSaleItem.BILL_AMT <= 0) continue;                                                                                      // 영수금액
                    if (cSaleItem.DC_PRMT_YN != "0") continue;                                                                                  // 할인가능 여부 

                    // 할인 Sum
                    if (cSaleItem.DC_DIV == ItemConst.PLU_DC_DIV.POS_DC)
                    {
                        nDCSum = CmUtil.DoubleAdd(nDCSum, cSaleItem.ITEM_DC_AMT);
                    }
                }
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return nDCSum;
        }

        /// <summary>
        ///  전체상품 할인 처리
        /// </summary>
        /// <param name="nSaleAmount"></param>
        /// <param name="nDCAvaAmount"></param>
        /// <param name="nAmount"></param>
        /// <returns></returns>
        public string GetSaleItemTotalDC(double nAmount)
        {
            double nSaleAmount = 0, nDCAvaAmount = 0;
            double nPrice = 0, nDCSum = 0, nRate = 0, nDCAmount = 0, nMaxPrice = 0;
            int iIndex = 0;

            string sRet = UserCom.RST_ERR;

            try
            {
                nDCSum = 0;

                nRate = 0;
                nDCAmount = 0;
                nMaxPrice = 0;

                if (nAmount <= 0) return UserCom.RST_OK;

                //  할인대상 금액이 있을때만 할인가능여부 체크(2017.05.20)
                sRet = CheckDCUseMode();                                                                // 할인 가능 여부 체크
                if (sRet != UserCom.RST_OK) return sRet;

                // 상품정보
                ArrayList aSaleItem = (ArrayList)StateObject.GetItemObject(Column.TR_PLU.ITEM);

                // 받을금액중 할인 안된 금액만 조회
                nSaleAmount = GetSaleItemDCTargerAmt(true);                             // 받을 금액
                // 받을금액중 할인 안된 금액만 조회
                nDCAvaAmount = GetSaleItemDCTargerAmt(false);                           // 할인 대상 금액
                if (m_cTrnStatus.Head.TotDcAmt > 0)
                {
                    // 할인 금액 존재시 받을금액은 할인 대상으로 한다.
                    nSaleAmount = nDCAvaAmount;
                }

                nDCAmount = nAmount;

                for (int iRow = 0; iRow < aSaleItem.Count; iRow++)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iRow];

                    if (cSaleItem.CANCEL_DIV == PosConst.CANCEL_DIV.CANCEL || cSaleItem.CANCEL_DIV_MAIN == PosConst.CANCEL_DIV.CANCEL) continue;// 지정취소
                    if (cSaleItem.DC_DIV == ItemConst.PLU_DC_DIV.FREE) continue;                                                                // 서비스(무료)
                    if (cSaleItem.ITEM_DIV != ItemConst.PLU_ITEM_DIV.NORMAL) continue;                                                          // 상품구분(일반)
                    if (cSaleItem.NONSALES_RSN_CD != "0") continue;                                                                             // 비매출구분
                    if (cSaleItem.BILLSPR_NO != m_cTrnStatus.Sale.BillSplitNo) continue;                                                        // 빌분리번호
                    if (cSaleItem.BILL_AMT <= 0) continue;                                                                                      // 영수금액
                    if (cSaleItem.DC_PRMT_YN != "0") continue;                                                                                  // 할인가능 여부 

                    // 할인 절삭
                    nDCAmount = CmUtil.MathRounds(nDCAmount, m_cPosStatus.Mst.DcRudDwLocMethd, CmUtil.IntParse(m_cPosStatus.Mst.DcRudDwLoc));

                    // 비율 = 상품금액 / 총판매가 * 100 
                    //nRate = CmUtil.DoubleMultiplication(CmUtil.DoubleDivision(cSaleItem.BILL_AMT, nDCAvaAmount), 100);

                    // 분배금액 = 상품금액 * 비율 / 100
                    //nPrice = CmUtil.DoubleDivision(CmUtil.DoubleMultiplication(nDCAmount, nRate), 100);

                    // 금액 배분 절삭
                    //nPrice = CmUtil.MathRounds(nPrice, m_cPosStatus.Mst.DcRudDwLocMethd, CmUtil.IntParse(m_cPosStatus.Mst.DcRudDwLoc));
                    nPrice = CmUtil.DoubleMultiplication(nDCAmount, CmUtil.DoubleDivision(cSaleItem.BILL_AMT, nDCAvaAmount));
                    nPrice = CmUtil.MathRounds(nPrice, m_cPosStatus.Mst.ItemRudDwLocMethd, CmUtil.IntParse(m_cPosStatus.Mst.ItemRudDwLoc));
                    if (nPrice > cSaleItem.BILL_AMT) continue;                                                                                  // 할인금액이 상품금액보다 클수 없음

                    // 상품할인 적용
                    cSaleItem.ITEM_DC_AMT = nPrice;
                    cSaleItem.DC_DIV = ItemConst.PLU_DC_DIV.POS_DC;         // 단품 할인 타입(00:정상, 01:무료(서비스), 02:임의할인,03:환경사랑DC,04:제품교환권,06:입점건물직원할인, 07:입점건물직원할인(적립)
                    cSaleItem.DC_TYPE = ItemConst.PLU_DC_TYPE.DC_SUM;       // 단품 할인 타입(0:없음, 1:소계할인, 2:단품할인)

                    // 분배후 짜투리 금액 체크용
                    nDCSum = CmUtil.DoubleAdd(nDCSum, nPrice);

                    // 최종 적용 상품 index
                    if (nMaxPrice == 0 || nMaxPrice >= cSaleItem.BILL_AMT)
                    {
                        nMaxPrice = cSaleItem.BILL_AMT;
                        iIndex = iRow;
                    }

                    // 상품행별 영수 금액 재계산 처리
                    m_cDataService.UpdatePluItemAmount(cSaleItem);
                }

                // 짜투리 금액 최종 적용 상품에 추가
                if (nDCSum != nDCAmount)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iIndex];

                    nPrice = 0;
                    nPrice = CmUtil.DoubleSubtraction(nDCAmount, nDCSum);

                    cSaleItem.ITEM_DC_AMT = CmUtil.DoubleAdd(cSaleItem.ITEM_DC_AMT, nPrice);              // 단품 할인 금액

                    // 상품행별 영수 금액 재계산 처리
                    m_cDataService.UpdatePluItemAmount(cSaleItem);
                }

                // 상품 판매가 계산
                m_cPluService.ItemAmountExeccute(true, true);

                sRet = UserCom.RST_OK;

            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }

        /// <summary>
        /// 전체상품 할인 취소 처리
        /// </summary>
        /// <returns></returns>
        public string GetSaleItemTotalDCCancel()
        {
            string sRet = UserCom.RST_ERR;

            try
            {
                // 상품정보
                ArrayList aSaleItem = (ArrayList)StateObject.GetItemObject(Column.TR_PLU.ITEM);

                for (int iRow = 0; iRow < aSaleItem.Count; iRow++)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iRow];

                    if (cSaleItem.CANCEL_DIV == PosConst.CANCEL_DIV.CANCEL || cSaleItem.CANCEL_DIV_MAIN == PosConst.CANCEL_DIV.CANCEL) continue;// 지정취소
                    if (cSaleItem.ITEM_DC_AMT == 0) continue;                                   // 할인 금액

                    // 상품할인 적용
                    cSaleItem.ITEM_DC_AMT = 0;
                    cSaleItem.DC_DIV = ItemConst.PLU_DC_DIV.NORMAL;
                    cSaleItem.DC_TYPE = ItemConst.PLU_DC_TYPE.NORMAL;                           // 단품 할인 타입(0:없음, 1:소계할인, 2:단품할인)

                    // 상품행별 영수 금액 재계산 처리
                    m_cDataService.UpdatePluItemAmount(cSaleItem);
                }

                // 상품 판매가 계산
                m_cPluService.ItemAmountExeccute(true, true);

                sRet = UserCom.RST_OK;

            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion

        #region 할인 가능 여부 체크
        /// <summary>
        /// 할인 가능 여부 체크
        /// </summary>
        /// <returns></returns>
        private string CheckDCUseMode()
        {
            string sRet = UserCom.RST_OK;

            try
            {
                // 상품정보
                ArrayList aSaleItem = (ArrayList)StateObject.GetItemObject(Column.TR_PLU.ITEM);
                for (int iRow = 0; iRow < aSaleItem.Count; iRow++)
                {
                    Column.TR_PLU.DATA cSaleItem = (Column.TR_PLU.DATA)aSaleItem[iRow];
                    if (cSaleItem.CANCEL_DIV == PosConst.CANCEL_DIV.CANCEL || cSaleItem.CANCEL_DIV_MAIN == PosConst.CANCEL_DIV.CANCEL) continue;// 지정취소

                    if (cSaleItem.ITEM_DC_AMT > 0)
                    {
                        if (cSaleItem.DC_DIV != ItemConst.PLU_DC_DIV.NORMAL || cSaleItem.ITEM_DC_AMT > 0)
                        // 소계할인
                        {
                            WinManager.ConfirmMessage(POS_MESSAGE.ERROR.MSG_0113);  // 기존 할인을 취소후 시도하여 주시기 바랍니다.
                            sRet = UserCom.ERROR;
                            return sRet;
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                WinManager.ExceptionMessage(System.Reflection.Assembly.GetExecutingAssembly().ManifestModule.Name,
                    System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.Name + "." + System.Reflection.MethodBase.GetCurrentMethod().Name + "()", ex.Message);
            }
            return sRet;
        }
        #endregion
    }
}
